# read Primates_exp10_RJMCMC.txt
read.table("Primates_exp10_RJMCMC.txt",header=T)->data0
names(data0)

# set pairs of "from" states for each of "to" states
para_set <- c(c(9,14),c(10,12),c(11,16),c(13,15))
q.names <- names(data0[,para_set])
q.names1 <- as.numeric(substr(q.names,2,2))
q.names2 <- as.numeric(substr(q.names,3,3))
state <- c("00","01","10","11")
q.names0 <- paste(q.names," (",state[q.names1],"->",state[q.names2],")",sep="")

# histories of MCMC samples
par(mfcol=c(2,4))
for (i in 1:8){
plot(data0[,para_set[i]],type="l",main=q.names0[i],ylab="",col=4)
}
par(mfcol=c(1,1))

# histograms of MCMC samples
par(mfcol=c(2,4))
for (i in 1:8){
hist(data0[,para_set[i]],main="",xlab=q.names0[i],col=4,
breaks=seq(0,100,by=0.5),probability=T,xlim=c(0,20))
}
par(mfcol=c(1,1))

# summary statistics of MCMC samples
summary(data0[,para_set])

# transition rate matrix
transition.rate <- apply(data0[,para_set],2,median)
rate0 <- matrix(0,nrow=4,ncol=4)
for (i in 1:8){
rate0[q.names1[i],q.names2[i]] <- transition.rate[i]
}
rate.any <- apply(rate0,1,sum)
diag(rate0) <- - rate.any

# simulated paths
simulate.path <- function(s.init,t.end,rate){
times <- time0 <- 0
states <- state0 <- s.init
time.end <- t.end
while(time0 < time.end){
   time.event <- rexp(1,rate=-rate[state0,state0])
   state0 <- sample((1:4)[-state0],1,prob=-rate0[state0,-state0]/rate[state0,state0])
   time0 <- time0 + time.event
   times <- c(times,time0)
   states <- c(states,state0)
}
   return(data.frame(times,states))
}

t.end <- 0.7
s.init <- 1
n.trial <- 50
state_OA <- c(0,0,1,1)
state_MS <- c(0,1,0,1)
plot(1,1,type="n",xlab="time",ylab="trial",cex.lab=1.5,xlim=c(0,t.end),ylim=c(1,n.trial))
for (trial in 1:n.trial){
result <- simulate.path(s.init,t.end,rate0)
abline(h=trial,lty=2)
#points(x=result[,1]-0.001,y=rep(trial,dim(result)[1]),pch=19,col=4-2*state_OA[result[,2]])
#points(x=result[,1]+0.01,y=rep(trial,dim(result)[1]),pch=20,col=4-2*state_MS[result[,2]])
points(x=result[,1],y=rep(trial,dim(result)[1]),pch=4+15*state_OA[result[,2]],
col=4-2*state_MS[result[,2]])
}
legend(0.8*t.end,0.95*n.trial,pch=c(4,4,19,19),col=c(4,2,4,2),
c("OA=0,MS=0","OA=0,MS=1","OA=1,MS=0","OA=1,MS=1"),bg="white")







